context("IL number")

test_that("usage", {
  if (requireNamespace("phyloTop")) {
     c1 <- treestats::ILnumber(extant_tree)
    c2 <- phyloTop::ILnumber(extant_tree)
    testthat::expect_equal(c1, c2)

    c3 <- treestats::ILnumber(treestats::phylo_to_l(extant_tree))
    testthat::expect_equal(c1, c3)

    c1 <- treestats::ILnumber(complete_tree)
    c2 <- phyloTop::ILnumber(complete_tree)
    testthat::expect_equal(c1, c2)

    c3 <- treestats::ILnumber(treestats::phylo_to_l(complete_tree))
    testthat::expect_equal(c1, c3)
  }
})

test_that("normalization", {
  c1 <- treestats::ILnumber(extant_tree)
  c2 <- treestats::ILnumber(extant_tree, normalization = "tips")
  testthat::expect_lt(c2, c1)
  c3 <- treestats::ILnumber(treestats::phylo_to_l(extant_tree),
                            normalization = "tips")
  testthat::expect_equal(c2, c3)

  stats1 <- c()
  stats2 <- c()
  for (n in seq(100, 200, by = 10)) {
    focal_tree <- ape::rphylo(n = n, birth = 1, death = 0)
    stats1 <- c(stats1, treestats::ILnumber(focal_tree))
    stats2 <- c(stats2, treestats::ILnumber(focal_tree, normalization = "tips"))
  }

  a1 <- cor(stats1, seq(100, 200, by = 10))
  a2 <- cor(stats2, seq(100, 200, by = 10))

  testthat::expect_lt(a2, a1)
  testthat::expect_lt(a2, 0.2)
})

test_that("polytomies", {
  # phyloTop does not apply to non-binary trees, treestats does!
  for (focal_tree in poly_trees) {
    local_stat <- try_stat(focal_tree, treestats::ILnumber)
    testthat::expect_true(!is.na(local_stat))
  }
})


test_that("wrong_object", {
  testthat::expect_error(
    treestats::ILnumber(10),
    "input object has to be phylo or ltable"
  )

  testthat::expect_error(
    treestats::ILnumber(list()),
    "input object has to be phylo or ltable"
  )
})
